==> modx-2.2.1-pl-ja.zip: modx-2.2.1-pl-ja/core/lexicon/ja/dashboards.inc.php <==
<?php
/**
 * Japanese language strings for Dashboards
 *
 * @package modx
 * @subpackage lexicon
 * @language ja
 * @author yamamoto http://kyms.jp
 * @author honda http://kogus.org
 */
$_lang['dashboard'] = 'ダッシュボード';
$_lang['dashboard_add'] = 'ダッシュボードを追加';
$_lang['dashboard_create'] = 'ダッシュボードを作成';
$_lang['dashboard_desc_name'] = 'このダッシュボードの名前';
$_lang['dashboard_desc_description'] = 'このダッシュボードについての短い説明';
$_lang['dashboard_desc_hide_trees'] = 'このオプションを有効にすると、ウェルカムページで左側のツリーが表示されなくなります。';
$_lang['dashboard_hide_trees'] = '左側のツリーを隠す';
$_lang['dashboard_duplicate'] = 'ダッシュボードを複製';
$_lang['dashboard_remove'] = 'ダッシュボードを削除';
$_lang['dashboard_remove_confirm'] = 'このダッシュボードを削除してもよろしいですか？';
$_lang['dashboard_update'] = 'ダッシュボード構成を編集';
$_lang['dashboard_err_ae_name'] = '"[[+name]]"という名前のダッシュボードはすでに存在しています！　別の名前を指定して下さい';
$_lang['dashboard_err_duplicate'] = 'ダッシュボードの複製時、エラーが発生しました。';
$_lang['dashboard_err_nf'] = 'ダッシュボードはありません。';
$_lang['dashboard_err_ns'] = 'ダッシュボードが指定されていません。';
$_lang['dashboard_err_ns_name'] = 'ダッシュボードの名前を指定してください。';
$_lang['dashboard_err_remove'] = 'ダッシュボードの削除時、エラーが発生しました。';
$_lang['dashboard_err_remove_default'] = 'デフォルトのダッシュボードは削除できません！';
$_lang['dashboard_err_save'] = 'ダッシュボードの保存時、エラーが発生しました。';
$_lang['dashboard_usergroup_add'] = 'ユーザーグループへダッシュボードを割り当てる';
$_lang['dashboard_usergroup_remove'] = 'ユーザーグループからダッシュボードを取り除く';
$_lang['dashboard_usergroup_remove_confirm'] = 'このユーザーグループがデフォルトのダッシュボードを使用するよう元に戻します。よろしいですか？';
$_lang['dashboard_usergroups.intro_msg'] = 'このダッシュボードを使用しているユーザーグループ';
$_lang['dashboard_widget_err_placed'] = 'このウィジェットはすでにダッシュボードへ配置されています！';
$_lang['dashboard_widgets.intro_msg'] = 'ダッシュボードに割り当てるウィジェットの管理を行います。ウィジェットはドラッグによる並び替えが可能です。';
$_lang['dashboards'] = 'ダッシュボード';
$_lang['dashboards.intro_msg'] = '管理画面用ダッシュボードを管理します。';
$_lang['rank'] = 'ランク';
$_lang['user_group_filter'] = 'By User Group';
$_lang['widget'] = 'ウィジェット';
$_lang['widget_content'] = 'ウィジェットの内容';
$_lang['widget_create'] = 'ウィジェットを作成';
$_lang['widget_err_ae_name'] = '"[[+name]]"という名前のウィジェットはすでに存在しています！　別の名前を指定して下さい';
$_lang['widget_err_nf'] = 'ウィジェットはありません。';
$_lang['widget_err_ns'] = 'ウィジェットが指定されていません！';
$_lang['widget_err_ns_name'] = 'ウィジェットの名前を指定してください。';
$_lang['widget_err_remove'] = 'ウィジェットの削除時に、エラーが発生しました。';
$_lang['widget_err_save'] = 'ウィジェットとの保存時に、エラーが発生しました。';
$_lang['widget_file'] = 'ファイル';
$_lang['widget_dashboards.intro_msg'] = 'このウィジェットが配置されているダッシュボード';
$_lang['widget_dashboard_remove'] = 'ウィジェットをダッシュボードから取り除く';
$_lang['widget_description_desc'] = 'ウィジェットの概要、または概要を示すレキシコンのエントリーキーを指定。';
$_lang['widget_html'] = 'HTML';
$_lang['widget_lexicon_desc'] = 'このウィジェットに読み込むレキシコントピックを指定します。名前と説明だけでなく、ウィジェット内のテキストを翻訳する場合に便利です。';
$_lang['widget_name_desc'] = 'ウィジェット名、またはレキシコンのエントリーキーを指定。';
$_lang['widget_new'] = 'ウィジェットの作成';
$_lang['widget_remove'] = 'ウィジェットの削除';
$_lang['widget_remove_confirm'] = 'このウィジェットを削除してよろしいですか？　この操作は取り消しできず、全てのダッシュボードからこのウィジェットは取り除かれます。';
$_lang['widget_remove_multiple'] = '複数のウィジェットを削除';
$_lang['widget_remove_multiple_confirm'] = 'これらのウィジェットを削除してよろしいですか？　この操作は取り消しできず、全てのダッシュボードからこれら全てのウィジェットは取り除かれます。';
$_lang['widget_namespace'] = 'ネームスペース';
$_lang['widget_namespace_desc'] = 'The Namespace that this widget will be loaded into. Useful for custom paths.';
$_lang['widget_php'] = 'インラインPHPウィジェット';
$_lang['widget_place'] = 'Place Widget';
$_lang['widget_size'] = 'サイズ';
$_lang['widget_size_desc'] = 'ウィジェットのサイズを指定します。"ハーフ"はウィジェット表示エリアの半分の横幅、"フル"はエリアの横幅いっぱいに表示されます。また、"ダブル"はエリアの横幅いっぱいに、2段分の高さで表示されます。';
$_lang['widget_size_double'] = 'ダブル(最大)';
$_lang['widget_size_full'] = 'フル(横幅いっぱい)';
$_lang['widget_size_half'] = 'ハーフ(半分の横幅)';
$_lang['widget_snippet'] = 'スニペット';
$_lang['widget_type'] = 'ウィジェットのタイプ';
$_lang['widget_type_desc'] = 'ウィジェットには以下のタイプがあります。"スニペット"ウィジェットは、MODXのスニペットの実行結果を返します。"HTML"ウィジェットは、入力されたHTMLコードをそのまま出力します。 "File" widgets are loaded directly from files, which can either return their output or the name of the modDashboardWidgetClass-extended class to load. "インラインPHP"ウィジェットはスニペットに似ていて、実行したいPHPコードを直接記入できます。';
$_lang['widget_unplace'] = 'ウィジェットを削除';
$_lang['widget_update'] = 'ウィジェットの設定を編集';
$_lang['widgets'] = 'ウィジェット';
$_lang['widgets.intro_msg'] = 'ダッシュボード用ウィジェットの作成や削除を行います。';
$_lang['w_configcheck'] = '設定チェック';
$_lang['w_configcheck_desc'] = '現在の設定が安全かチェックし、問題点を表示します。';
$_lang['w_newsfeed'] = 'MODXニュースフィード';
$_lang['w_newsfeed_desc'] = 'MODXの公式ニュースを表示します（システム設定で指定されたフィードを使用）。';
$_lang['w_recentlyeditedresources'] = '最近更新されたリソース';
$_lang['w_recentlyeditedresources_desc'] = '最近ユーザーによって作成または編集されたリソースを一覧します。';
$_lang['w_securityfeed'] = 'MODXセキュリティフィード';
$_lang['w_securityfeed_desc'] = 'MODXの公式セキュリティ情報を表示します（システム設定で指定されたフィードを使用）。';
$_lang['w_whosonline'] = 'オンライン中のユーザー';
$_lang['w_whosonline_desc'] = '現在オンライン中のユーザーを一覧します。';

==> modx-2.3.3-pl-ja.zip: modx-2.3.3-pl-ja/core/lexicon/ja/dashboards.inc.php <==
<?php
/**
 * English language strings for Dashboards
 *
 * @package modx
 * @subpackage lexicon
 * @language en
 */
$_lang['dashboard'] = 'ダッシュボード';
$_lang['dashboard_add'] = 'ダッシュボードを追加';
$_lang['dashboard_create'] = 'ダッシュボードを作成';
$_lang['dashboard_desc_name'] = 'このダッシュボードの名前';
$_lang['dashboard_desc_description'] = 'このダッシュボードについての短い説明';
$_lang['dashboard_desc_hide_trees'] = 'このオプションを有効にすると、ウェルカムページで左側のツリーが表示されなくなります。';
$_lang['dashboard_hide_trees'] = '左側のツリーを隠す';
$_lang['dashboard_duplicate'] = 'ダッシュボードを複製';
$_lang['dashboard_remove'] = 'ダッシュボードを削除';
$_lang['dashboard_remove_confirm'] = 'このダッシュボードを削除してもよろしいですか？';
$_lang['dashboard_remove_multiple'] = 'Remove Dashboards';
$_lang['dashboard_remove_multiple_confirm'] = 'Are you sure you want to remove the selected Dashboards?';
$_lang['dashboard_update'] = 'ダッシュボード構成を編集';
$_lang['dashboard_err_ae_name'] = '"[[+name]]"という名前のダッシュボードはすでに存在しています！　別の名前を指定してください';
$_lang['dashboard_err_duplicate'] = 'ダッシュボードの複製時、エラーが発生しました。';
$_lang['dashboard_err_nf'] = 'ダッシュボードはありません。';
$_lang['dashboard_err_ns'] = 'ダッシュボードが指定されていません。';
$_lang['dashboard_err_ns_name'] = 'ダッシュボードの名前を指定してください。';
$_lang['dashboard_err_remove'] = 'ダッシュボードの削除時、エラーが発生しました。';
$_lang['dashboard_err_remove_default'] = 'デフォルトのダッシュボードは削除できません！';
$_lang['dashboard_err_save'] = 'ダッシュボードの保存時、エラーが発生しました。';
$_lang['dashboard_usergroup_add'] = 'ユーザーグループへダッシュボードを割り当てる';
$_lang['dashboard_usergroup_remove'] = 'ユーザーグループからダッシュボードを取り除く';
$_lang['dashboard_usergroup_remove_confirm'] = 'このユーザーグループがデフォルトのダッシュボードを使用するよう元に戻します。よろしいですか？';
$_lang['dashboard_usergroups.intro_msg'] = 'このダッシュボードを使用しているユーザーグループ';
$_lang['dashboard_widget_err_placed'] = 'このウィジェットはすでにダッシュボードへ配置されています！';
$_lang['dashboard_widgets.intro_msg'] = 'ダッシュボードに割り当てるウィジェットの管理を行います。ウィジェットはドラッグによる並び替えが可能です。';
$_lang['dashboards'] = 'ダッシュボード';
$_lang['dashboards.intro_msg'] = '管理画面用ダッシュボードを管理します。';
$_lang['rank'] = 'ランク';
$_lang['user_group_filter'] = 'By ユーザーグループ';
$_lang['widget'] = 'ウィジェット';
$_lang['widget_content'] = 'ウィジェットの内容';
$_lang['widget_create'] = 'ウィジェットを作成';
$_lang['widget_err_ae_name'] = '"[[+name]]"という名前のウィジェットはすでに存在しています！　別の名前を指定してください';
$_lang['widget_err_nf'] = 'ウィジェットはありません。';
$_lang['widget_err_ns'] = 'ウィジェットが指定されていません！';
$_lang['widget_err_ns_name'] = 'ウィジェットの名前を指定してください。';
$_lang['widget_err_remove'] = 'ウィジェットの削除時に、エラーが発生しました。';
$_lang['widget_err_save'] = 'ウィジェットとの保存時に、エラーが発生しました。';
$_lang['widget_file'] = 'ファイル';
$_lang['widget_dashboards.intro_msg'] = 'このウィジェットが配置されているダッシュボード';
$_lang['widget_dashboard_remove'] = 'ウィジェットをダッシュボードから取り除く';
$_lang['widget_description_desc'] = 'ウィジェットの概要、または概要を示すレキシコンのエントリーキーを指定。';
$_lang['widget_html'] = 'HTML';
$_lang['widget_lexicon_desc'] = 'このウィジェットに読み込むレキシコントピックを指定します。名前と説明だけでなく、ウィジェット内のテキストを翻訳する場合に便利です。';
$_lang['widget_name_desc'] = 'ウィジェット名、またはレキシコンのエントリーキーを指定。';
$_lang['widget_new'] = 'ウィジェットの作成';
$_lang['widget_remove'] = 'ウィジェットの削除';
$_lang['widget_remove_confirm'] = 'このウィジェットを削除してよろしいですか？　この操作は取り消しできず、全てのダッシュボードからこのウィジェットは取り除かれます。';
$_lang['widget_remove_multiple'] = '複数のウィジェットを削除';
$_lang['widget_remove_multiple_confirm'] = 'これらのウィジェットを削除してよろしいですか？　この操作は取り消しできず、全てのダッシュボードからこれら全てのウィジェットは取り除かれます。';
$_lang['widget_namespace'] = 'ネームスペース';
$_lang['widget_namespace_desc'] = 'このウィジェットがロードされているネームスペース。カスタムパスの利用時に便利です。';
$_lang['widget_php'] = 'インラインPHPウィジェット';
$_lang['widget_place'] = 'ウィジェットの場所';
$_lang['widget_size'] = 'サイズ';
$_lang['widget_size_desc'] = 'ウィジェットのサイズを指定します。"ハーフ"はウィジェット表示エリアの半分の横幅、"フル"はエリアの横幅いっぱいに表示されます。また、"ダブル"はエリアの横幅いっぱいに、2段分の高さで表示されます。';
$_lang['widget_size_double'] = 'ダブル（最大）';
$_lang['widget_size_full'] = 'フル（横幅いっぱい）';
$_lang['widget_size_half'] = 'ハーフ（半分の横幅）';
$_lang['widget_snippet'] = 'スニペット';
$_lang['widget_type'] = 'ウィジェットのタイプ';
$_lang['widget_type_desc'] = 'ウィジェットには以下のタイプがあります。"スニペット"ウィジェットは、MODXのスニペットの実行結果を返します。"HTML"ウィジェットは、入力されたHTMLコードをそのまま出力します。 "ファイル"ウィジェットは、ファイルから直接読み込まれます。ファイルは、直接出力を返すか、modDashboardWidgetClassクラスを継承している必要があります。 "インラインPHP"ウィジェットはスニペットに似ていて、実行したいPHPコードを直接記入できます。';
$_lang['widget_unplace'] = 'ウィジェットを削除';
$_lang['widget_update'] = 'ウィジェットの設定を編集';
$_lang['widgets'] = 'ウィジェット';
$_lang['widgets.intro_msg'] = 'ダッシュボード用ウィジェットの作成や削除を行います。';

$_lang['w_configcheck'] = '設定チェック';
$_lang['w_configcheck_desc'] = '現在の設定が安全かチェックし、問題点を表示します。';
$_lang['w_newsfeed'] = 'MODXニュースフィード';
$_lang['w_newsfeed_desc'] = 'MODXの公式ニュースを表示します（システム設定で指定されたフィードを使用）。';
$_lang['w_recentlyeditedresources'] = '更新されたリソース';
$_lang['w_recentlyeditedresources_desc'] = 'ユーザーによって作成または編集されたリソースを一覧します。';
$_lang['w_securityfeed'] = 'MODXセキュリティフィード';
$_lang['w_securityfeed_desc'] = 'MODXの公式セキュリティ情報を表示します（システム設定で指定されたフィードを使用）。';
$_lang['w_whosonline'] = 'オンライン中のユーザー';
$_lang['w_whosonline_desc'] = '現在オンライン中のユーザーを一覧します。';
